#!/bin/bash
DIALOG=${DIALOG=dialog}
PED=${PED=parted}
CONFIG="/etc/image-installer.conf"
HDPARM=$(HDPARM=hdparm)
tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/test$$
tempfile2=`tempfile 2>/dev/null` || tempfile2=/tmp/test2$$
tempfiler1=`tempfile 2>/dev/null` || tempfiler1=/tmp/test2$$
tempfiler2=`tempfile 2>/dev/null` || tempfiler2=/tmp/test2$$

trap "rm -f $tempfile" 0 1 2 5 15
trap "rm -f $tempfile2" 0 1 2 5 15
trap "rm -f $tempfiler1" 0 1 2 5 15
trap "rm -f $tempfiler2" 0 1 2 5 15

ALLIDEDRIVES=`cat /proc/partitions |grep -E '.+[1-9].+[0-9].+[0-9].+hd[a-z]$' | awk '{print $4}'`
ALLSCSIDRIVES=`cat /proc/partitions  |grep -E '(.+[1-9].+[0-9].+[0-9].+sd[a-z]$)' | awk '{print $4}'`

for DISK in $ALLIDEDRIVES
do
$HDPARM -q -c1 -q -d1 -q -u1 -q -m16 /dev/$DISK
done

function debug {
	if [ ${DEBUG} == "1" ] ; then
	echo -e -n "$@"
	fi
}

function gen_templlist {
	CNT=1
	cd ${BASEMOUNT}
	for IMG in `find -type d -maxdepth 1 |grep -v "^\.$" |sed -e s@"\./"@""@g`
	do
	echo $IMG $CNT off	
	CNT=`expr $CNT + 1`
	done
}

function gen_disklist {
	CNT=1
	for DISK in $ALLIDEDRIVES $ALLSCSIDRIVES
	do
	
		WRK=$DISK
		echo $WRK $CNT off
		CNT=`expr $CNT + 1`
	
	done
}

function prepare_setup {	
	if [ -f $CONFIG ]; then
		. $CONFIG
		if [ -n "$DESTMOUNT" ]; then
			mkdir -p "$DESTMOUNT"
		fi
		if [ -n "$BASEMOUNT" ]; then
			mkdir -p "$BASEMOUNT"
			case $IMAGELOCATION in
				NFS)
					mount -t nfs $IMAGELOCATION_NFS $BASEMOUNT
					
				;;
				FTP)
					echo "IMAGELOCATION: $IMAGELOCATION not implemented"
					exit 1
				;;
				HTTP)
					echo "IMAGELOCATION: $IMAGELOCATION not implemented"
					exit 1
				;;
				DIR)
					mount $IMAGELOCATION_DIR $BASEMOUNT
				;;
				*)
					echo "IMAGELOCTION: $IMAGELOCATION not supported"
					exit 1
				;;
			esac
		else
			echo "no base mountpoint in config"
			exit 1
		fi
	else
		echo "configuration file not found"
		exit 1
	fi
}

function get_archiver {
#	echo "ARCHIVE: $1"
	TGZ=`echo $1 | grep -E '(tar.gz$|tgz$)'`
	BZ=`echo $1 | grep -E '(tar.bz2$|tbz2$)'`
	if [ -n "$TGZ" ]; then
		echo "tar -xz -f $1"
	elif [ -n "$BZ" ]; then
		echo "tar -xj -f $1"
	else
		echo "not implemented"
	fi
}


################### start up the stuff #############################
prepare_setup

######## IMAGE SELECT ##########
$DIALOG --backtitle "$TITLE" \
	--title "Image selection" --clear \
	--radiolist "Please select image to install: " 20 75 10 `gen_templlist` 2> $tempfile2
retval=$?
choice=`cat $tempfile2`
case $retval in 
	0)
		clear
		if [ -z "`cat $tempfile2`" ]; then
			echo "no image selected"
			exit 1
		fi
		;;
	1)
		echo "cancel pressed"
		exit 1
		;;
	255)
		echo "esc pressed"
		exit 255
		;;
esac

if [ -z "`grep -i raid $tempfile2`" ] ; then
	RAID=0
	######### DISK SELECT ##########
	$DIALOG --backtitle "$TITLE" \
	--title "Disk Partitioner" --clear \
	--radiolist "Please select disk for installation: " 20 75 10 `gen_disklist` 2> $tempfile
	
	retval=$?

	choice=`cat $tempfile`

else
	RAID=1
	$DIALOG --backtitle "$TITLE" \
		--title "Disk Partitioner" --clear \
		--radiolist "Please select first raid disk for installation: " 20 75 10 `gen_disklist` 2> $tempfiler1
	retval1=$?
	$DIALOG --backtitle "$TITLE" \
        	--title "Disk Partitioner" --clear \
	        --radiolist "Please select second raid disk for installation: " 20 75 10 `gen_disklist` 2> $tempfiler2
	retval2=$?

	if [ "$retval1" == "$retval2" ] ; then
		retval=$retval1
	else 
		retval=1
	fi
fi

case $retval in 
	0)
		clear
			if [ "$RAID" == 0 ] ; then
				. ${BASEMOUNT}/`cat ${tempfile2}`/parts/functions
				prepare_disk `cat $tempfile`
				mount_disk `cat $tempfile` ${DESTMOUNT}
				base_install ${DESTMOUNT}
				extra_install ${DESTMOUNT} ${BASEMOUNT} `cat ${tempfile2}`
				template_install ${DESTMOUNT} ${BASEMOUNT} `cat ${tempfile2}`
				mbr_install `cat $tempfile` ${DESTMOUNT}
				umount_disk ${DESTMOUNT}
				sys_reboot ${DESTMOUNT}
			else
			 	. ${BASEMOUNT}/`cat ${tempfile2}`/parts/functions
				prepare_disk `cat $tempfiler1` `cat $tempfiler2`
				mount_disk `cat $tempfiler1` ${DESTMOUNT}
				base_install ${DESTMOUNT}
                                extra_install ${DESTMOUNT} ${BASEMOUNT} `cat ${tempfile2}`
                                template_install ${DESTMOUNT} ${BASEMOUNT} `cat ${tempfile2}`
                                mbr_install `cat $tempfiler1` ${DESTMOUNT}
                                umount_disk ${DESTMOUNT}
                                sys_reboot ${DESTMOUNT}
			fi


		;;
	1)
		echo "cancel pressed"
		exit 1
		;;
	255)
		echo "esc pressed"
		exit 255
		;;
esac
umount $BASEMOUNT
exit 0
